@@ -25,7 +25,7 @@
 #endif
 
 #include <glib.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "yelp-pager.h"
 #include "yelp-marshal.h"
@@ -38,6 +38,8 @@
 #define d(x)
 #endif
 
+#define YELP_PAGER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), YELP_TYPE_PAGER, YelpPagerPriv))
+
 struct _YelpPagerPriv {
     YelpDocInfo     *doc_info;
     YelpPagerState   state;
@@ -169,6 +171,8 @@ pager_class_init (YelpPagerClass *klass)
 	 NULL, NULL,
 	 yelp_marshal_VOID__VOID,
 	 G_TYPE_NONE, 0);
+
+    g_type_class_add_private (klass, sizeof (YelpPagerPriv));
 }
 
 static void
@@ -176,8 +180,7 @@ pager_init (YelpPager *pager)
 {
     YelpPagerPriv *priv;
 
-    priv = g_new0 (YelpPagerPriv, 1);
-    pager->priv = priv;
+    pager->priv = priv = YELP_PAGER_GET_PRIVATE (pager);
 
     priv->doc_info = NULL;
     priv->state = YELP_PAGER_STATE_NEW;
@@ -366,6 +369,9 @@ yelp_pager_get_page (YelpPager *pager, const gchar *frag_id)
     const gchar *page_id =
 	YELP_PAGER_GET_CLASS (pager)->resolve_frag (pager, frag_id);
 
+    if (page_id == NULL)
+	return NULL;
+
     page = (YelpPage *) g_hash_table_lookup (pager->priv->page_hash, page_id);
 
     return (const YelpPage *) page;
